@@ -29,6 +29,10 @@ class TestFeed(unittest.TestCase):
         timestr2 = '25:01:01'
         self.assertEqual(timestr_mod_24(timestr2), timestr1)
         
+    def test_to_km(self):
+        units = 'mi'
+        self.assertEqual(to_km(1, units), 1.6093)
+
     def test_get_segment_length(self):
         s = LineString([(0, 0), (1, 0)])
         p = Point((1/2, 0))
@@ -42,10 +46,10 @@ class TestFeed(unittest.TestCase):
         # Test distance units check
         self.assertRaises(AssertionError, Feed, 
           path='gtfs_toolkit/tests/cairns_gtfs.zip', 
-          distance_units='bingo')
+          original_units='bingo')
         # Test other stuff
         portland = Feed('gtfs_toolkit/tests/portland_gtfs.zip', 
-          distance_units='ft')
+          original_units='ft')
         for feed in [cairns, portland]:
             self.assertIsInstance(feed.routes, pd.core.frame.DataFrame)
             self.assertIsInstance(feed.stops, pd.core.frame.DataFrame)
@@ -57,14 +61,6 @@ class TestFeed(unittest.TestCase):
                 self.assertIsInstance(feed.calendar_dates, 
                   pd.core.frame.DataFrame)
 
-    def test_to_km(self):
-        feed = cairns
-        feed.distance_units = 'mi'
-        f = feed.to_km
-        self.assertEqual(f(1), 1.6093)
-        # Reset
-        feed.distance_units = 'km'
-
     def test_get_dates(self):
         feed = cairns
         dates = feed.get_dates()
@@ -169,6 +165,42 @@ class TestFeed(unittest.TestCase):
         # Date columns should contain only zeros and ones
         self.assertEqual(set(stops_activity[dates].values.flatten()), {0, 1})
 
+    def test_add_dist_to_stop_times(self):
+        feed = cairns
+        st1 = feed.stop_times
+        trips_stats = feed.get_trips_stats()
+        st2 = feed.add_dist_to_stop_times(trips_stats)
+
+        # Check that colums of st2 equal the columns of st1 plus
+        # a shape_dist_traveled column
+        cols1 = list(st1.columns.values) + ['shape_dist_traveled']
+        cols2 = list(st2.columns.values)
+        self.assertEqual(set(cols1), set(cols2))
+
+        # Check that within each trip the shape_dist_traveled column 
+        # is monotonically increasing
+        for name, group in st2.groupby('trip_id'):
+            sdt = list(group['shape_dist_traveled'].values)
+            self.assertEqual(sdt, sorted(sdt))
+
+    def test_add_dist_to_shapes(self):
+        feed = cairns
+        s1 = feed.shapes
+        trips_stats = feed.get_trips_stats()
+        s2 = feed.add_dist_to_shapes()
+
+        # Check that colums of st2 equal the columns of st1 plus
+        # a shape_dist_traveled column
+        cols1 = list(s1.columns.values) + ['shape_dist_traveled']
+        cols2 = list(s2.columns.values)
+        self.assertEqual(set(cols1), set(cols2))
+
+        # Check that within each trip the shape_dist_traveled column 
+        # is monotonically increasing
+        for name, group in s2.groupby('shape_id'):
+            sdt = list(group['shape_dist_traveled'].values)
+            self.assertEqual(sdt, sorted(sdt))
+
     def test_get_stops_stats(self):
         feed = cairns
         dates = feed.get_first_week()
@@ -264,5 +296,6 @@ class TestFeed(unittest.TestCase):
             # Should have correct column names
             self.assertEqual(arts.columns.names, col_names)   
 
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
